@@ -16,7 +16,7 @@
 __author__ = "Anton Panasenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.8"
+__version__ = "1.0.9"
 __email__ = "apanasenko@qubell.com"
 
 import unittest
@@ -40,7 +40,16 @@ def values(names):
                     if isinstance(v, dict):
                         findReturnValues(v)
                     elif isinstance(v, unicode):
-                        value = yaml.load(v)
+                        #TODO fix return values
+                        try:
+                            value = yaml.safe_load(v)
+                        except Exception:
+                            import re
+                            try:
+                                value = yaml.safe_load(re.sub(r': ([:/?a-zA-Z_0-9-\.]+)', r': "\1"', v))
+                            except Exception:
+                                value = None
+
                         if not isinstance(value, dict) and k in names.keys():
                             kwargs.update({names[k]: value})
                         elif isinstance(value, dict):
